@@ -4,7 +4,14 @@ const sizeMap = {
   large: 64
 }
 
-export default function getSvgProps({'aria-label': ariaLabel, className, size, verticalAlign, svgDataByHeight}) {
+export default function getSvgProps({
+  'aria-label': ariaLabel,
+  className,
+  fill = 'currentColor',
+  size,
+  verticalAlign,
+  svgDataByHeight
+}) {
   const height = sizeMap[size] || size
   const naturalHeight = closestNaturalHeight(Object.keys(svgDataByHeight), height)
   const naturalWidth = svgDataByHeight[naturalHeight].width
@@ -19,11 +26,12 @@ export default function getSvgProps({'aria-label': ariaLabel, className, size, v
     viewBox: `0 0 ${naturalWidth} ${naturalHeight}`,
     width,
     height,
-    fill: 'currentColor',
+    fill,
     style: {
       display: 'inline-block',
       userSelect: 'none',
-      verticalAlign
+      verticalAlign,
+      overflow: 'visible'
     },
     dangerouslySetInnerHTML: {__html: path}
   }
